@@ -19,6 +19,72 @@ except ModuleNotFoundError:  # pragma: no cover - optional dependency
     TestClient = None  # type: ignore
 
 
+def test_cache_store_respects_configured_storage_root(tmp_path: Path) -> None:
+    storage_root = tmp_path / "custom-root" / "nested"
+    config_path = tmp_path / "config.toml"
+    config_path.write_text(
+        f"""
+[server]
+storage_root = "{storage_root.as_posix()}"
+""".strip(),
+        encoding="utf-8",
+    )
+    config = load_config(config_path)
+
+    assert config.server.storage_root == storage_root
+
+    store = cache_mod.CacheStore(config.server.storage_root)
+
+    expected_cache_dir = storage_root / "cache"
+    assert store._root == expected_cache_dir
+    assert expected_cache_dir.is_dir()
+
+
+@pytest.mark.skipif(TestClient is None, reason="fastapi is not available")
+def test_cache_files_materialize_under_configured_storage_root(tmp_path: Path) -> None:
+    src = tmp_path / "src"
+    src.mkdir()
+    build = tmp_path / "build"
+    storage_root = tmp_path / "custom-storage"
+    config_path = tmp_path / "config.toml"
+    config_path.write_text(
+        f"""
+[server]
+storage_root = "{storage_root.as_posix()}"
+""".strip(),
+        encoding="utf-8",
+    )
+    route_text = (
+        "+++\n"
+        "id = \"config-cache\"\n"
+        "path = \"/config-cache\"\n"
+        "title = \"Config cache\"\n"
+        "[cache]\n"
+        "order_by = [\"bird\"]\n"
+        "rows_per_page = 1\n"
+        "+++\n\n"
+        "```sql\nSELECT 'duck' AS bird\n```\n"
+    )
+    write_sidecar_route(src, "config-cache", route_text)
+    compile_routes(src, build)
+    routes = load_compiled_routes(build)
+    config = load_config(config_path)
+    app = create_app(routes, config)
+    client = TestClient(app)
+
+    response = client.get("/config-cache")
+    assert response.status_code == 200
+
+    cache_root = storage_root / "cache"
+    route_cache_dir = cache_root / "config-cache"
+    assert route_cache_dir.is_dir()
+    parquet_pages = list(route_cache_dir.rglob("page-*.parquet"))
+    assert parquet_pages
+
+    cwd_cache_dir = Path.cwd() / "storage" / "cache" / "config-cache"
+    assert not cwd_cache_dir.exists()
+
+
 @pytest.mark.skipif(TestClient is None, reason="fastapi is not available")
 def test_cache_hit_skips_duckdb(tmp_path: Path, monkeypatch: pytest.MonkeyPatch) -> None:
     src = tmp_path / "src"
@@ -589,6 +655,60 @@ def test_invariant_filters_apply_to_html_views(tmp_path: Path) -> None:
     assert "<td>Finance</td>" not in html_text
 
 
+@pytest.mark.skipif(TestClient is None, reason="fastapi is not available")
+def test_invariant_filters_coerce_numeric_strings(tmp_path: Path) -> None:
+    src = tmp_path / "src"
+    src.mkdir()
+    build = tmp_path / "build"
+    route_text = (
+        "+++\n"
+        "id = \"numeric_invariant\"\n"
+        "path = \"/numeric_invariant\"\n"
+        "title = \"Numeric invariant filters\"\n"
+        "[params.OperationCode]\n"
+        "type = \"str\"\n"
+        "required = false\n"
+        "ui_label = \"Operation\"\n"
+        "[cache]\n"
+        "rows_per_page = 50\n"
+        "order_by = [\"RouteCode\", \"OperationCode\"]\n"
+        "invariant_filters = [ { param = \"OperationCode\", column = \"OperationCode\" } ]\n"
+        "+++\n\n"
+        "```sql\n"
+        "SELECT * FROM (VALUES\n"
+        "    ('A', 0),\n"
+        "    ('A', 10),\n"
+        "    ('B', 20)\n"
+        ") AS t(RouteCode, OperationCode)\n"
+        "ORDER BY RouteCode, OperationCode\n"
+        "```\n"
+    )
+    write_sidecar_route(src, "numeric_invariant", route_text)
+    compile_routes(src, build)
+    routes = load_compiled_routes(build)
+    config = load_config(None)
+    config.server.storage_root = tmp_path / "storage"
+    config.server.storage_root.mkdir()
+    app = create_app(routes, config)
+    client = TestClient(app)
+
+    ten_response = client.get(
+        "/numeric_invariant",
+        params={"format": "json", "OperationCode": "10"},
+    )
+    assert ten_response.status_code == 200
+    ten_payload = ten_response.json()
+    assert [row["OperationCode"] for row in ten_payload["rows"]] == [10]
+
+    zero_response = client.get(
+        "/numeric_invariant",
+        params={"format": "json", "OperationCode": "0"},
+    )
+    assert zero_response.status_code == 200
+    zero_payload = zero_response.json()
+    assert [row["OperationCode"] for row in zero_payload["rows"]] == [0]
+
+
 @pytest.mark.skipif(TestClient is None, reason="fastapi is not available")
 def test_invariant_select_defaults_to_unique_values(tmp_path: Path) -> None:
     src = tmp_path / "src"
@@ -639,6 +759,78 @@ def test_invariant_select_defaults_to_unique_values(tmp_path: Path) -> None:
     assert "<option value='Manufacturing'>Manufacturing</option>" in text
 
 
+@pytest.mark.skipif(TestClient is None, reason="fastapi is not available")
+def test_invariant_html_form_filters_after_numeric_selection(tmp_path: Path) -> None:
+    src = tmp_path / "src"
+    src.mkdir()
+    build = tmp_path / "build"
+    route_text = (
+        "+++\n"
+        "id = \"invariant_year_division\"\n"
+        "path = \"/invariant_year_division\"\n"
+        "title = \"Year and division selector\"\n"
+        "[params.year]\n"
+        "type = \"str\"\n"
+        "default = \"\"\n"
+        "ui_label = \"Year\"\n"
+        "ui_control = \"select\"\n"
+        "[params.division]\n"
+        "type = \"str\"\n"
+        "default = \"\"\n"
+        "ui_label = \"Division\"\n"
+        "ui_control = \"select\"\n"
+        "[cache]\n"
+        "rows_per_page = 10\n"
+        "order_by = [\"Year\", \"Division\"]\n"
+        "invariant_filters = [\n"
+        "    { param = \"year\", column = \"Year\" },\n"
+        "    { param = \"division\", column = \"Division\" },\n"
+        "]\n"
+        "[html_t]\n"
+        "show_params = [\"year\", \"division\"]\n"
+        "+++\n\n"
+        "```sql\n"
+        "SELECT * FROM (VALUES\n"
+        "    (2023, 'Engineering', 'ENG-01'),\n"
+        "    (2023, 'Finance', 'FIN-02'),\n"
+        "    (2024, 'Engineering', 'ENG-10'),\n"
+        "    (2024, 'Operations', 'OPS-11')\n"
+        ") AS t(Year, Division, Code)\n"
+        "WHERE ({{ year }} = '' OR Year = CAST({{ year }} AS INTEGER))\n"
+        "  AND ({{ division }} = '' OR Division = {{ division }})\n"
+        "ORDER BY Year, Division\n"
+        "```\n"
+    )
+    write_sidecar_route(src, "invariant_year_division", route_text)
+    compile_routes(src, build)
+    routes = load_compiled_routes(build)
+    config = load_config(None)
+    config.server.storage_root = tmp_path / "storage"
+    config.server.storage_root.mkdir()
+    app = create_app(routes, config)
+    client = TestClient(app)
+
+    json_response = client.get(
+        "/invariant_year_division",
+        params={"format": "json", "year": "2024"},
+    )
+    assert json_response.status_code == 200
+    payload = json_response.json()
+    assert [row["Year"] for row in payload["rows"]] == [2024, 2024]
+    assert [row["Division"] for row in payload["rows"]] == ["Engineering", "Operations"]
+
+    html_response = client.get(
+        "/invariant_year_division",
+        params={"format": "html_t", "year": "2024"},
+    )
+    assert html_response.status_code == 200
+    text = html_response.text
+    assert "<option value='2024' selected>2024</option>" in text
+    assert "<option value='Engineering'>Engineering</option>" in text
+    assert "<option value='Operations'>Operations</option>" in text
+    assert "<option value='Finance'>Finance</option>" not in text
+
+
 @pytest.mark.skipif(TestClient is None, reason="fastapi is not available")
 def test_html_filters_render_for_invariants_without_params(tmp_path: Path) -> None:
     src = tmp_path / "src"
