@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 import datetime as dt
+from decimal import Decimal
 
 import pyarrow as pa
 
@@ -15,8 +16,10 @@ def table_to_records(table: pa.Table) -> list[dict[str, object]]:
 
 
 def json_friendly(value: object) -> object:
-    if isinstance(value, (dt.date, dt.datetime)):
+    if isinstance(value, (dt.date, dt.datetime, dt.time)):
         return value.isoformat()
+    if isinstance(value, Decimal):
+        return format(value, "f") if value.is_finite() else str(value)
     return value
 
 
